@@ -7,7 +7,7 @@ from .gpu import (get_free_gpu, subprocess, set_cuda_visible_devices)
 from .path import (is_filepath, check_file_exist, fopen, symlink,
                    scandir, find_vcs_root, mkdir_or_exist)
 
-from .logging import (get_logger, get_root_logger, print_log, coloring_string, coloring_print)
+from .logging import (get_logger, get_root_logger, print_log)
 
 from .processbar import (ProgressBar, track_progress, init_pool,
                          track_parallel_progress, track_iter_progress)
@@ -16,13 +16,11 @@ from .timer import (Timer, check_time)
 
 from .model import (check_model, check_grad, check_params, check_optimizer, register_hook, parameter_count, parameter_count_table)
 
-from .debug import (check, display, set_seed, check_rand_state, myTimer)
+from .debug import (check, display, check_rand_state, myTimer)
 
-from .checkpoint import (_load_checkpoint, load_checkpoint, load_state_dict, load_url_dist,
-                         resume, save_checkpoint, weights_to_cpu, get_state_dict, is_module_wrapper)
-
-from .io import (BaseFileHandler, JsonHandler, PickleHandler, YamlHandler, TxtHandler,
-                 dump, load, register_handler, dict_from_file, list_from_file)
+from .checkpoint import (_load_checkpoint, load_checkpoint, load_state_dict,
+                         load_url_dist, resume, save_checkpoint, save_summary,
+                         weights_to_cpu, get_state_dict, is_module_wrapper)
 
 from .memory import retry_if_cuda_oom
 
